@@ -10,7 +10,12 @@ class ResourceRelease(VisualizableBlock):
     (needs to be present in the entities resources list)"""
 
     def __init__(
-        self, env, name, xy=None, ways=None, resource: Resource = None,
+        self,
+        env,
+        name,
+        xy=None,
+        ways=None,
+        resource: Resource = None,
     ):
         super().__init__(env, name, xy=xy, ways=ways)
 
