@@ -11,7 +11,9 @@ class Sink(VisualizableBlock):
     def process_entity(self, entity):
         yield self.env.timeout(0)
 
+        entity.time_of_last_arrival = self.env.now
         self.on_enter(entity)
+        self.overall_count_in += 1
         self.entities.append(entity)
         self.block_resource.release(entity.block_resource_request)
         self.on_exit(entity, None)
