@@ -6,6 +6,9 @@ from abc import abstractmethod
 class ScaledCanvas:
     """overview of canvas methods called from visualizer"""
 
+    def __init__(self, scale: float) -> None:
+        self.scale = scale
+
     @abstractmethod
     def load_image_file(self, path: str):
         """takes file path and returns loaded image file reference"""
@@ -46,7 +49,6 @@ class ScaledCanvas:
     def get_height(self) -> int:
         """returns heigth"""
 
-    @staticmethod
-    def _scale_coords(x_y: tuple, scale: float):
+    def _scale_coords(self, x_y: tuple):
         """returns tuple values multiplied by factor"""
-        return tuple(map(lambda c: int(c * scale), x_y))
+        return tuple(map(lambda c: int(c * self.scale), x_y))
