@@ -42,7 +42,11 @@ class SimController:
         self.should_run.value = True
         self.sim_process = Process(
             target=self.simulation.simulate,
-            args=(self.shared_state, self.should_run, self.factor,),
+            args=(
+                self.shared_state,
+                self.should_run,
+                self.factor,
+            ),
         )
 
     def pause_sim(self):
